@@ -91,7 +91,7 @@ class Samples:
             header = list(temp[0])
 
             # label name doesn't match
-            if label_colname not in header:
+            if label_colname in header:
                 loc = header.index(label_colname)
             else:
                 raise ValueError("Label name mismatch.\nAvailable names: " + ', '.join(header))
